@@ -32,7 +32,9 @@ RELEX_OPTS="\
 
 CLASSPATH="-classpath \
 bin:\
+/usr/local/share/java/opennlp-tools-1.4.3.jar:\
 /usr/local/share/java/opennlp-tools-1.3.0.jar:\
+/usr/local/share/java/maxent-2.5.2.jar:\
 /usr/local/share/java/maxent-2.4.0.jar:\
 /usr/local/share/java/trove.jar:\
 /usr/local/share/java/jwnl-1.4rc2.jar:\
