@@ -86,7 +86,9 @@ public class Antecedents
 		for (int i=0; i<ante_list.size(); i++)
 		{
 			PhraseTree ante = ante_list.get(i);
+System.out.println("duuuude ante="+ ante);
 			FeatureNode nante = ante.getPhraseLeader();
+System.out.println("duuuude noante="+ nante);
 			if (nante != null) rlist.add(nante);
 		}
 		return rlist;
@@ -230,6 +232,8 @@ public class Antecedents
 	{
 		FeatureNode ph = pt.getPhraseLeader();
 		if (ph == null) return "";
+System.out.println("duuuude ante pt=" + pt);
+System.out.println("duuuude ante leader=" + PhraseTree.toString(ph));
 
 		ph = ph.get("str");
 		if (ph == null) return "";
