@@ -85,10 +85,16 @@ public class DocSplitterOpenNLPImpl implements DocSplitter
 	/* --------------------------------------------------------------- */
 	public DocSplitterOpenNLPImpl()
 	{
-		buffer = "";
+		buffer = null;
 		initialize();
 	}
 
+	public boolean operational()
+	{
+		if (detector == null) return false;
+		return true;
+	}
+
 	private void initialize()
 	{
 		if (detector == null)
@@ -150,6 +156,7 @@ public class DocSplitterOpenNLPImpl implements DocSplitter
 	 */
 	public void addText(String newText)
 	{
+		if (null == buffer) buffer = "";
 		buffer += newText;
 	}
 
@@ -158,7 +165,7 @@ public class DocSplitterOpenNLPImpl implements DocSplitter
 	 */
 	public void clearBuffer()
 	{
-		buffer = "";
+		buffer = null;
 	}
 
 	/**
@@ -171,7 +178,7 @@ public class DocSplitterOpenNLPImpl implements DocSplitter
 		if (detector == null)
 		{
 			String rc = buffer;
-			buffer = "";
+			buffer = null;
 			return rc;
 		}
 
