@@ -517,6 +517,7 @@ public class FeatureNode extends Atom
 	/**
 	 * Export feature structures as Prolog lists.
 	 * XXX deprecated -- caller should use the PrologList class directly
+	 * @deprecated
 	 */
 	public String toPrologList(FeatureNameFilter filter, boolean indent)
 	{
@@ -567,6 +568,15 @@ public class FeatureNode extends Atom
 		return target.getValue();
 	}
 
+	public String pathValue(String str) 
+	{
+		FeaturePath path = new FeaturePath(str);
+		FeatureNode target = pathTarget(path);
+		if (target == null) return null;
+		if (!target.isValued()) return null;
+		return target.getValue();
+	}
+
 	/**
 	 * Like pathTarget(), but creates the path if it doesn't already exist.
 	 * setting its target to the passed target. If forceTarget is false, then an
@@ -644,7 +654,7 @@ public class FeatureNode extends Atom
 	/**
 	 * Debugging function -- return string containing key names.
 	 */
-	public String _prt_vals()
+	public String _prt_keys()
 	{
 		if (isValued()) return "";
 		String ret = "";
@@ -657,6 +667,25 @@ public class FeatureNode extends Atom
 		return ret;
 	}
 
+	/**
+	 * Debugging function -- return list of key-value pairs.
+	 */
+	public String _prt_vals()
+	{
+		if (isValued()) return "this=" + value;
+		String ret = "";
+		Iterator<String> j = getFeatureNames().iterator();
+		while (j.hasNext()) {
+			String stuff = j.next();
+			ret += stuff + "=";
+			String v = pathValue("<" + stuff + ">");
+			if (v == null) ret += "@";
+			else ret += v;
+			ret += "\n";
+		}
+		return ret;
+	}
+
 	// Test method
 	static public void main(String[] args)
 	{
