@@ -53,6 +53,8 @@ public class PhraseLeader
 		if (fn_name_source == null) return;
 		FeatureNode phr = fn_name_source.get("phr-head");
 		if (phr == null) return;
+System.out.println("duuuude cahll _pds for ="+PhraseTree.toString(fn_name_source) +
+"= the leader is=" + fn._prt_vals());
 		phr.set("phr-leader", fn);
 	}
 
@@ -64,12 +66,15 @@ public class PhraseLeader
 		}
 		public Boolean BinaryHeadCB(FeatureNode from)
 		{
+System.out.println("duude binary head");
 			_phraseHeads(from);
 			return false;
 		}
 		public Boolean BinaryRelationCB(String relation, FeatureNode from, FeatureNode to)
 		{
-			_phraseHeads(to);
+System.out.println("duude binary relation");
+			// Headword is always the first word.
+			_phraseHeads(from);
 			return false;
 		}
 	}
@@ -80,6 +85,10 @@ public class PhraseLeader
 	 * have only one leaf under them. Assume that the leaf
 	 * must be the phrase leader. So e.g. "(PP for (NP fun))"
 	 * "fun" will be declared as the leader of "for fun".
+	 *
+	 * Note that is only makes sense for PP and NP, but not for 
+	 * S or VP. So for example: (S (VP drop (NP it))) the head
+	 * for S and VP is "drop", and not "it". 
 	 */
 	private static class leafHeads implements FeatureNodeCallback
 	{
@@ -88,12 +97,16 @@ public class PhraseLeader
 			FeatureNode leaf = PhraseTree.getOneLeafOnly(fn);
 			if (leaf != null)
 			{
+				fn = fn.get("phr-head");
+System.out.println("duuuude llleafffy heads for type=" + fn.get("phr-type")._prt_vals());
+
+System.out.println("duuuude llleafffy heads for " + PhraseTree.toString(leaf));
 				leaf = leaf.get("phr-head");
 				leaf = leaf.get("phr-next");
 				leaf = leaf.get("phr-word");
 				leaf = leaf.get("ref");
 
-				fn = fn.get("phr-head");
+System.out.println("duuuude cahll llleafffy heads for " + PhraseTree.toString(fn) +" val="+ leaf._prt_vals());
 				fn.set("phr-leader", leaf);
 			}
 			return false;
@@ -103,8 +116,8 @@ public class PhraseLeader
 	/* -------------------------------------------------------------------- */
 	public static void markup(FeatureNode sent)
 	{
-		RelationForeach.foreach(sent, new phraseHeads());
 		PhraseTree.foreach(sent, new leafHeads());
+		RelationForeach.foreach(sent, new phraseHeads());
 	}
 };
 
